@@ -6,9 +6,9 @@
 from typing import List, Dict, Union
 
 from pymysql.connections import Connection
+from pydantic import BaseModel, validator
 
 from pymysqldao import msg_
-from pymysqldao.decorator_ import all_param_type_check
 from pymysqldao.err_ import (
     ParamTypeError,
     ParamBoolFalseError,
@@ -17,6 +17,73 @@ from pymysqldao.err_ import (
 from pymysqldao.dao import base_
 
 
+class VSelectById(BaseModel):
+    # 主键值
+    id_value: str = 1
+
+    # 主键名，默认为"id"
+    primary_key: str = 'id'
+
+    @validator("id_value")
+    def id_value_cant_none(cls, v):
+        if not v:
+            raise ValueError(msg_.param_cant_none("id_value"))
+        return str(v)
+
+
+class VSelectByField(BaseModel):
+    # 字段名
+    field_key: str
+
+    # 字段值
+    field_value: str
+
+    # 限制显示的结果数量
+    # 默认为20
+    limit_size: int = 20
+
+    @validator("field_key")
+    def field_key_cant_none(cls, v):
+        if not v:
+            raise ValueError(msg_.param_cant_none("field_key"))
+        return v
+
+    @validator("field_value")
+    def field_value_cant_none(cls, v):
+        if not v:
+            raise ValueError(msg_.param_cant_none("field_value"))
+        return v
+
+
+class VSelectByIdList(BaseModel):
+    # 包含需要查询的所有id值的list, eg: [1, 2, 3], ["1", "2", "3"], ["1", 2, "3"];
+    id_list: List[Union[str, int]]
+
+    # 限制显示的结果数量
+    limit_size: int = 20
+
+    # 主键名默认是"id"；如果主键名不是"id"，应该显式的给出；
+    primary_key: str = "id"
+
+    @validator("id_list")
+    def id_list_pre_validation(cls, v):
+        if not v:
+            raise ValueError(msg_.param_cant_none("id_list"))
+        # if not isinstance(v, list):
+        #     raise TypeError(msg_.param_only_accept_list("id_list"))
+        # for item in v:
+        #     if type(item) == str or type(item) == int:
+        #         ...
+        #     else:
+        #         raise ParamTypeError(msg_.param_should_listUnionStrInt("id_list"))
+        return v
+
+
+class VSelectList(BaseModel):
+    #         :param limit_size: 查询的limit值；可以为空，默认值是20；
+    limit_size: int = 20
+
+
 class BaseDao(base_.DatabaseDao):
     def __init__(self, connection: Connection, table_name: str):
         super(BaseDao, self).__init__(connection)
@@ -27,16 +94,17 @@ class BaseDao(base_.DatabaseDao):
             # __表示受保护的属性，不希望别人在外部修改
             self.__table_name = table_name
 
-    def select_by_id(self, id_value: Union[int, str], primary_key='id') -> Dict:
+    def validation_select_by_id(self, params: VSelectById) -> Dict:
         """
 
-        select * from table_name where primary_key = id_value
+        select * from table_name where `id` = id_value
 
-        :param id_value: 主键值
-        :param primary_key: 主键名，默认为"id"
         :return: Dict
         """
-        query_list = self.select_by_field(id_value, field_key=primary_key)
+        id_value = params.id_value
+        primary_key = params.primary_key
+        query_list = self.select_by_field(primary_key, id_value)
+
         if len(query_list) == 1:
             return query_list[0]
         else:
@@ -44,37 +112,30 @@ class BaseDao(base_.DatabaseDao):
             base_.LOGGER.error(msg)
             raise PrimaryKeyError(msg)
 
+    def select_by_id(self, id_value: Union[str, int], primary_key: str = 'id') -> Dict:
+        params_input = {
+            "id_value": id_value,
+            "primary_key": primary_key,
+        }
+        data = VSelectById(**params_input)
+        return self.validation_select_by_id(data)
+
     # @all_param_type_check
-    def select_by_id_list(self, id_list: List[Union[str, int]], limit_size=0, primary_key="id"):
+    def select_by_id_list(self, id_list: List[Union[str, int]], limit_size: int = 20, primary_key: str = "id"):
+        """select * from table where primary_key in id_list"""
+        params_input = {
+            "id_list": id_list,
+            "limit_size": limit_size,
+            "primary_key": primary_key,
+        }
+        return self.validation_select_by_id_list(VSelectByIdList(**params_input))
+
+    def validation_select_by_id_list(self, params: VSelectByIdList):
         """
-
         select * from table where primary_key in id_list
-
-        :param id_list: 包含需要查询的所有id值的list, eg: [1, 2, 3], ["1", "2", "3"], ["1", 2, "3"];
-        :param primary_key: 主键名默认是"id"；如果主键名不是"id"，应该显式的给出；
-        :param limit_size: 限制显示的结果数量
         :return: List[Dict] / None
         """
-        params_list: list = list(locals().keys())
-        param_id_list: str = params_list[params_list.index("id_list")]
-        param_limit_size: str = params_list[params_list.index("limit_size")]
-        param_primary_key: str = params_list[params_list.index("primary_key")]
-
-        if not id_list:
-            raise ParamBoolFalseError(msg_.param_cant_none(param_id_list))
-        if not isinstance(id_list, list):
-            raise ParamTypeError(msg_.param_only_accept_list(param_id_list))
-
-        if type(primary_key) != str:
-            raise ParamTypeError(msg_.param_only_accept_str(param_primary_key))
-
-        for item in id_list:
-            if not item:
-                raise ParamTypeError(msg_.param_cant_none(param_id_list))
-            if type(item) == str or type(item) == int:
-                ...
-            else:
-                raise ParamTypeError(msg_.param_should_listUnionStrInt("id_list"))
+        id_list, limit_size, primary_key = params.id_list, params.limit_size, params.primary_key
 
         sql = f"select * from {self.__table_name} where {primary_key} in %s"
         try:
@@ -94,22 +155,21 @@ class BaseDao(base_.DatabaseDao):
         finally:
             return result if result else None
 
-    @all_param_type_check
-    def select_by_field(self, field_value: Union[str, int], field_key: str, limit_size=None) -> List[Dict[str, object]]:
+    def validation_select_by_field(self, params: VSelectByField) -> List[Dict[str, object]]:
         """
 
-        select * from table_name where field_key = field_value
+        select * from table_name where `field_key` = field_value
 
-        :param field_value: 字段值
-        :param field_key: 字段名
-        :param limit_size: 限制显示的结果数量
         :return: List<Dict> / Dict （查询出的结果为单个，会返回Dict
         """
-        if not limit_size:
-            limit_size = 20
+        field_key = params.field_key
+        field_value = params.field_value
+        limit_size = params.limit_size
 
-        if not field_value:
-            raise ParamBoolFalseError(msg_.param_cant_none("field_value"))
+        # assert not field_value
+
+        # if not field_value:
+        #     raise ParamBoolFalseError(msg_.param_cant_none("field_value"))
 
         sql = f"select * from {self.__table_name} where {field_key} = %s"
         try:
@@ -129,16 +189,36 @@ class BaseDao(base_.DatabaseDao):
         finally:
             return result if result else None
 
-    def select_list(self, limit_size=0):
+    def select_by_field(self, key: str, value: str, limit: int = 20):
+        """
+
+        :param key: 字段名
+        :param value: 字段值
+        :param limit:
+        :return:
+        """
+        input_params = {
+            "field_key": key,
+            "field_value": value,
+            "limit_size": limit,
+        }
+        data = VSelectByField(**input_params)
+        return self.validation_select_by_field(data)
+
+    def select_list(self, limit: int = 20):
+        params_input = {
+            "limit_size": limit
+        }
+        return self.validation_select_list(VSelectList(**params_input))
+
+    def validation_select_list(self, params: VSelectList):
         """
 
         select * from table_name limit limit_size
 
-        :param limit_size: 查询的limit值；可以为空，默认值是20；
         :return: List[Dict]
         """
-        if type(limit_size) != int:
-            raise ParamTypeError(msg_.param_only_accept_int("limit_size"))
+        limit_size = params.limit_size
 
         sql = f"select * from {self.__table_name}"
         try:
@@ -158,7 +238,7 @@ class BaseDao(base_.DatabaseDao):
         finally:
             return result if result is not None else None
 
-    def insert_one(self, obj_dict: Dict, primary_key="id"):
+    def insert_one(self, obj_dict: Dict, primary_key: str = "id"):
         """
 
         insert into table_name () values ()
@@ -167,6 +247,7 @@ class BaseDao(base_.DatabaseDao):
         :param primary_key: 主键名，默认为"id"
         :return: affect_rows_num（1）
         """
+
         def generate_sql(obj: Dict):
             field_list = []
             value_list = []
@@ -221,6 +302,7 @@ class BaseDao(base_.DatabaseDao):
         :param primary_key:
         :return:
         """
+
         def generate_sql(obj_dict):
             field_value_list = []
             for field, value in obj_dict.items():
@@ -237,7 +319,7 @@ class BaseDao(base_.DatabaseDao):
 
         if primary_key == "id" and primary_key not in obj_dict:  # not obj_dict.has_key("id")
             raise PrimaryKeyError("如果主键列名不是`id`，请显式的指出主键列名")
-        
+
         try:
             with self._connection.cursor() as cursor:
                 sql = generate_sql(obj_dict)
@@ -265,6 +347,7 @@ class BaseDao(base_.DatabaseDao):
         :param field_key: 字段名
         :return:
         """
+
         def get_primary_key(obj: Dict):
             """从item中获取primary的名，一般是'id'"""
             first_key = list(obj.keys())[0]
